@@ -42,7 +42,7 @@ describe 'keystone::client' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-keystoneclient' }
         when 'RedHat'
