@@ -116,19 +116,15 @@ describe 'keystone::resource::service_identity' do
       )}
     end
 
-    context 'when trying to create an endpoint without service_type (will be dropped in Mitaka)' do
+    context 'when trying to create an endpoint without service_type' do
       let :params do
+        required_params.delete(:service_type)
         required_params.merge(
           :configure_service => false,
-          :service_type      => false,
         )
       end
-      it { is_expected.to contain_keystone_endpoint("RegionOne/#{title}").with(
-        :ensure       => 'present',
-        :public_url   => 'http://7.7.7.7:9696',
-        :internal_url => 'http://10.0.0.1:9696',
-        :admin_url    => 'http://192.168.0.1:9696',
-      )}
+
+      it { is_expected.to raise_error(Puppet::Error) }
     end
 
     context 'when trying to create a service without service_type' do
@@ -169,8 +165,9 @@ describe 'keystone::resource::service_identity' do
       )}
 
       it { is_expected.to contain_keystone_user_role("#{title}@services").with(
-        :ensure => 'present',
-        :roles  => ['admin'],
+        :ensure      => 'present',
+        :roles       => ['admin'],
+        :user_domain => 'userdomain',
       )}
 
       it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
@@ -179,7 +176,7 @@ describe 'keystone::resource::service_identity' do
     context 'with user and project domain' do
       let :params do
         required_params.merge({
-          :user_domain => 'userdomain',
+          :user_domain    => 'userdomain',
           :project_domain => 'projdomain',
         })
       end
@@ -196,8 +193,10 @@ describe 'keystone::resource::service_identity' do
       )}
 
       it { is_expected.to contain_keystone_user_role("#{title}@services").with(
-        :ensure => 'present',
-        :roles  => ['admin'],
+        :ensure         => 'present',
+        :roles          => ['admin'],
+        :user_domain    => 'userdomain',
+        :project_domain => 'projdomain',
       )}
 
       it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
@@ -222,8 +221,68 @@ describe 'keystone::resource::service_identity' do
       )}
 
       it { is_expected.to contain_keystone_user_role("#{title}@services").with(
-        :ensure => 'present',
-        :roles  => ['admin'],
+        :ensure         => 'present',
+        :roles          => ['admin'],
+        :user_domain    => 'defaultdomain',
+        :project_domain => 'defaultdomain',
+      )}
+
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
+    end
+
+    context 'with user and default domain' do
+      let :params do
+        required_params.merge({
+          :user_domain    => 'userdomain',
+          :default_domain => 'defaultdomain',
+        })
+      end
+
+      it { is_expected.to contain_keystone_user(title).with(
+        :ensure   => 'present',
+        :password => 'secrete',
+        :email    => 'neutron@localhost',
+        :domain   => 'userdomain',
+      )}
+
+      it { is_expected.to contain_keystone_domain('userdomain').with(
+        :ensure   => 'present',
+      )}
+
+      it { is_expected.to contain_keystone_user_role("#{title}@services").with(
+        :ensure         => 'present',
+        :roles          => ['admin'],
+        :user_domain    => 'userdomain',
+        :project_domain => 'defaultdomain',
+      )}
+
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
+    end
+
+    context 'with project and default domain' do
+      let :params do
+        required_params.merge({
+          :project_domain => 'projdomain',
+          :default_domain => 'defaultdomain',
+        })
+      end
+
+      it { is_expected.to contain_keystone_user(title).with(
+        :ensure   => 'present',
+        :password => 'secrete',
+        :email    => 'neutron@localhost',
+        :domain   => 'defaultdomain',
+      )}
+
+      it { is_expected.to contain_keystone_domain('defaultdomain').with(
+        :ensure   => 'present',
+      )}
+
+      it { is_expected.to contain_keystone_user_role("#{title}@services").with(
+        :ensure         => 'present',
+        :roles          => ['admin'],
+        :user_domain    => 'defaultdomain',
+        :project_domain => 'projdomain',
       )}
 
       it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
