@@ -37,29 +37,29 @@ describe Puppet::Type.type(:keystone_user_role).provider(:openstack) do
     describe '#create' do
       before(:each) do
 
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role assignment', 'list', '--quiet', '--format', 'csv',
                 ['--names', '--project', 'project1_id', '--user', 'user1_id'])
-          .returns('"ID","Name","Project","User"
+          .and_return('"ID","Name","Project","User"
 "role1_id","role1","project1","user1"
 "role2_id","role2","project1","user1"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'add',
                 ['role1', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'add',
                 ['role2', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('project', 'show', '--format', 'shell',
                 ['project1', '--domain', 'domain1'])
-          .returns('name="project1"
+          .and_return('name="project1"
 id="project1_id"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('user', 'show', '--format', 'shell',
                 ['user1', '--domain', 'domain1'])
-          .returns('name="user1"
+          .and_return('name="user1"
 id="user1_id"
 ')
       end
@@ -105,28 +105,28 @@ id="user1_id"
     describe '#destroy' do
       it 'removes all the roles from a user' do
         provider.instance_variable_get('@property_hash')[:roles] = ['role1', 'role2']
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'remove',
                 ['role1', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'remove',
                 ['role2', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('project', 'show', '--format', 'shell',
                 ['project1', '--domain', 'domain1'])
-          .returns('name="project1"
+          .and_return('name="project1"
 id="project1_id"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('user', 'show', '--format', 'shell',
                 ['user1', '--domain', 'domain1'])
-          .returns('name="user1"
+          .and_return('name="user1"
 id="user1_id"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role assignment', 'list', '--quiet', '--format', 'csv',
                 ['--names', '--project', 'project1_id', '--user', 'user1_id'])
-          .returns('"ID","Name","Project","User"
+          .and_return('"ID","Name","Project","User"
 ')
         provider.destroy
         expect(provider.exists?).to be_falsey
@@ -135,23 +135,23 @@ id="user1_id"
 
     describe '#exists' do
       subject(:response) do
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role assignment', 'list', '--quiet', '--format', 'csv',
                 ['--names', '--project', 'project1_id', '--user', 'user1_id'])
-          .returns('"ID","Name","Project","User"
+          .and_return('"ID","Name","Project","User"
 "role1_id","role1","project1","user1"
 "role2_id","role2","project1","user1"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('project', 'show', '--format', 'shell',
                 ['project1', '--domain', 'domain1'])
-          .returns('name="project1"
+          .and_return('name="project1"
 id="project1_id"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('user', 'show', '--format', 'shell',
                 ['user1', '--domain', 'domain1'])
-          .returns('name="user1"
+          .and_return('name="user1"
 id="user1_id"
 ')
         provider.exists?
@@ -170,29 +170,29 @@ id="user1_id"
       end
 
       it 'applies new roles' do
-        provider.expects(:roles).returns(%w(role_one role_two))
-        described_class.expects(:openstack)
+        expect(provider).to receive(:roles).and_return(%w(role_one role_two))
+        expect(described_class).to receive(:openstack)
           .with('role', 'remove',
                 ['role_one', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'remove',
                 ['role_two', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'add',
                 ['one', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('role', 'add',
                 ['two', '--project', 'project1_id', '--user', 'user1_id'])
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('project', 'show', '--format', 'shell',
                 ['project_one', '--domain', 'Default'])
-          .returns('name="project_one"
+          .and_return('name="project_one"
 id="project1_id"
 ')
-        described_class.expects(:openstack)
+        expect(described_class).to receive(:openstack)
           .with('user', 'show', '--format', 'shell',
                 ['user_one', '--domain', 'Default'])
-          .returns('name="role_one"
+          .and_return('name="role_one"
 id="user1_id"
 ')
         provider.roles = %w(one two)
